EXPORTS
	__20TSendingCapabilitiesiii @ 1 NONAME ; TSendingCapabilities::TSendingCapabilities(int, int, int)
	AppendAttachmentL__12CMessageDataRC7TDesC16 @ 2 NONAME R3UNUSED ; CMessageData::AppendAttachmentL(TDesC16 const &)
	AppendBccAddressL__12CMessageDataRC7TDesC16T1 @ 3 NONAME R3UNUSED ; CMessageData::AppendBccAddressL(TDesC16 const &, TDesC16 const &)
	AppendCcAddressL__12CMessageDataRC7TDesC16T1 @ 4 NONAME R3UNUSED ; CMessageData::AppendCcAddressL(TDesC16 const &, TDesC16 const &)
	AppendToAddressL__12CMessageDataRC7TDesC16T1 @ 5 NONAME R3UNUSED ; CMessageData::AppendToAddressL(TDesC16 const &, TDesC16 const &)
	AvailableServicesL__7CSendUiRt13RPointerArray1Z19CSendingServiceInfoG4TUid @ 6 NONAME R3UNUSED ; CSendUi::AvailableServicesL(RPointerArray<CSendingServiceInfo> &, TUid)
	CanAddMtmL__10CSendAppUiG4TUidG20TSendingCapabilities @ 7 NONAME ; CSendAppUi::CanAddMtmL(TUid, TSendingCapabilities)
	CanAddMtmL__11CSendBaseUiG4TUidG20TSendingCapabilities @ 8 NONAME ; CSendBaseUi::CanAddMtmL(TUid, TSendingCapabilities)
	CanSendBioMessage__10CSendAppUiG4TUid @ 9 NONAME R3UNUSED ; CSendAppUi::CanSendBioMessage(TUid)
	CanSendBioMessage__11CSendBaseUiG4TUid @ 10 NONAME R3UNUSED ; CSendBaseUi::CanSendBioMessage(TUid)
	CanSendBioMessage__C7CSendUiG4TUid @ 11 NONAME R3UNUSED ; CSendUi::CanSendBioMessage(TUid) const
	CommandIsValidL__10CSendAppUiiG20TSendingCapabilitiesPt9CArrayFix1Z4TUid @ 12 NONAME ; CSendAppUi::CommandIsValidL(int, TSendingCapabilities, CArrayFix<TUid> *)
	CommandIsValidL__11CSendBaseUiiG20TSendingCapabilitiesPt9CArrayFix1Z4TUid @ 13 NONAME ; CSendBaseUi::CommandIsValidL(int, TSendingCapabilities, CArrayFix<TUid> *)
	ConstructL__11CSendBaseUiiP15CEikHotKeyTable @ 14 NONAME R3UNUSED ; CSendBaseUi::ConstructL(int, CEikHotKeyTable *)
	CopyLC__C19CSendingServiceInfo @ 15 NONAME R3UNUSED ; CSendingServiceInfo::CopyLC(void) const
	CreateAndSendMessageL__10CSendAppUiG4TUidPC9CRichTextP12MDesC16ArrayT1T3T3i @ 16 NONAME ; CSendAppUi::CreateAndSendMessageL(TUid, CRichText const *, MDesC16Array *, TUid, MDesC16Array *, MDesC16Array *, int)
	CreateAndSendMessageL__10CSendAppUiiPC9CRichTextP12MDesC16ArrayG4TUidT3T3i @ 17 NONAME ; CSendAppUi::CreateAndSendMessageL(int, CRichText const *, MDesC16Array *, TUid, MDesC16Array *, MDesC16Array *, int)
	CreateAndSendMessageL__11CSendBaseUiG4TUidPC9CRichTextP12MDesC16ArrayT1T3T3i @ 18 NONAME ; CSendBaseUi::CreateAndSendMessageL(TUid, CRichText const *, MDesC16Array *, TUid, MDesC16Array *, MDesC16Array *, int)
	CreateAndSendMessageL__11CSendBaseUiiPC9CRichTextP12MDesC16ArrayG4TUidT3T3i @ 19 NONAME ; CSendBaseUi::CreateAndSendMessageL(int, CRichText const *, MDesC16Array *, TUid, MDesC16Array *, MDesC16Array *, int)
	CreateAndSendMessageL__7CSendUiG4TUidPC12CMessageDataT1i @ 20 NONAME ; CSendUi::CreateAndSendMessageL(TUid, CMessageData const *, TUid, int)
	CreateAndSendMessagePopupQueryL__10CSendAppUiRC7TDesC16G20TSendingCapabilitiesPC9CRichTextP12MDesC16ArrayG4TUidT4T4Pt9CArrayFix1Z4TUidi @ 21 NONAME ; CSendAppUi::CreateAndSendMessagePopupQueryL(TDesC16 const &, TSendingCapabilities, CRichText const *, MDesC16Array *, TUid, MDesC16Array *, MDesC16Array *, CArrayFix<TUid> *, int)
	CreateAndSendMessagePopupQueryL__11CSendBaseUiRC7TDesC16G20TSendingCapabilitiesPC9CRichTextP12MDesC16ArrayG4TUidT4T4Pt9CArrayFix1Z4TUidi @ 22 NONAME ; CSendBaseUi::CreateAndSendMessagePopupQueryL(TDesC16 const &, TSendingCapabilities, CRichText const *, MDesC16Array *, TUid, MDesC16Array *, MDesC16Array *, CArrayFix<TUid> *, int)
	CreateAndSendMessagePopupQueryWithSubjectL__10CSendAppUiRC7TDesC16T1G20TSendingCapabilitiesPC9CRichTextP12MDesC16ArrayG4TUidT5N35Pt9CArrayFix1Z4TUidi @ 23 NONAME ; CSendAppUi::CreateAndSendMessagePopupQueryWithSubjectL(TDesC16 const &, TDesC16 const &, TSendingCapabilities, CRichText const *, MDesC16Array *, TUid, MDesC16Array *, MDesC16Array *, MDesC16Array *, MDesC16Array *, CArrayFix<TUid> *, int)
	CreateAndSendMessagePopupQueryWithSubjectL__11CSendBaseUiRC7TDesC16T1G20TSendingCapabilitiesPC9CRichTextP12MDesC16ArrayG4TUidT5N35Pt9CArrayFix1Z4TUidi @ 24 NONAME ; CSendBaseUi::CreateAndSendMessagePopupQueryWithSubjectL(TDesC16 const &, TDesC16 const &, TSendingCapabilities, CRichText const *, MDesC16Array *, TUid, MDesC16Array *, MDesC16Array *, MDesC16Array *, MDesC16Array *, CArrayFix<TUid> *, int)
	CreateAndSendMessageWithSubjectL__10CSendAppUiG4TUidRC7TDesC16PC9CRichTextP12MDesC16ArrayT1T4N34i @ 25 NONAME ; CSendAppUi::CreateAndSendMessageWithSubjectL(TUid, TDesC16 const &, CRichText const *, MDesC16Array *, TUid, MDesC16Array *, MDesC16Array *, MDesC16Array *, MDesC16Array *, int)
	CreateAndSendMessageWithSubjectL__10CSendAppUiiRC7TDesC16PC9CRichTextP12MDesC16ArrayG4TUidT4N34i @ 26 NONAME ; CSendAppUi::CreateAndSendMessageWithSubjectL(int, TDesC16 const &, CRichText const *, MDesC16Array *, TUid, MDesC16Array *, MDesC16Array *, MDesC16Array *, MDesC16Array *, int)
	CreateAndSendMessageWithSubjectL__11CSendBaseUiG4TUidRC7TDesC16PC9CRichTextP12MDesC16ArrayT1T4N34i @ 27 NONAME ; CSendBaseUi::CreateAndSendMessageWithSubjectL(TUid, TDesC16 const &, CRichText const *, MDesC16Array *, TUid, MDesC16Array *, MDesC16Array *, MDesC16Array *, MDesC16Array *, int)
	CreateAndSendMessageWithSubjectL__11CSendBaseUiiRC7TDesC16PC9CRichTextP12MDesC16ArrayG4TUidT4N34i @ 28 NONAME ; CSendBaseUi::CreateAndSendMessageWithSubjectL(int, TDesC16 const &, CRichText const *, MDesC16Array *, TUid, MDesC16Array *, MDesC16Array *, MDesC16Array *, MDesC16Array *, int)
	CreateDimmableMtmArrayL__10CSendAppUiRC12MDesC16Array @ 29 NONAME R3UNUSED ; CSendAppUi::CreateDimmableMtmArrayL(MDesC16Array const &)
	CreateDimmableMtmArrayL__11CSendBaseUiRC12MDesC16Array @ 30 NONAME R3UNUSED ; CSendBaseUi::CreateDimmableMtmArrayL(MDesC16Array const &)
	DRMConfirmAndFilterProtectedFilesL__23CSendUiFileRightsEngineR16CDesC16ArrayFlatG4TUid @ 31 NONAME R3UNUSED ; CSendUiFileRightsEngine::DRMConfirmAndFilterProtectedFilesL(CDesC16ArrayFlat &, TUid)
	DisplaySendCascadeMenuL__10CSendAppUiR12CEikMenuPanePt9CArrayFix1Z4TUid @ 32 NONAME R3UNUSED ; CSendAppUi::DisplaySendCascadeMenuL(CEikMenuPane &, CArrayFix<TUid> *)
	DisplaySendCascadeMenuL__11CSendBaseUiR12CEikMenuPanePt9CArrayFix1Z4TUid @ 33 NONAME R3UNUSED ; CSendBaseUi::DisplaySendCascadeMenuL(CEikMenuPane &, CArrayFix<TUid> *)
	DisplaySendMenuItemL__10CSendAppUiR12CEikMenuPaneiG20TSendingCapabilities @ 34 NONAME ; CSendAppUi::DisplaySendMenuItemL(CEikMenuPane &, int, TSendingCapabilities)
	DisplaySendMenuItemL__11CSendBaseUiR12CEikMenuPaneiG20TSendingCapabilities @ 35 NONAME ; CSendBaseUi::DisplaySendMenuItemL(CEikMenuPane &, int, TSendingCapabilities)
	ExpandArrayPropertiesLC__23CSendUiFileRightsEngineRC12MDesC16Array @ 36 NONAME R3UNUSED ; CSendUiFileRightsEngine::ExpandArrayPropertiesLC(MDesC16Array const &)
	FinishL__20CSendUiIdleMtmLoader @ 37 NONAME R3UNUSED ; CSendUiIdleMtmLoader::FinishL(void)
	MMEFilesSendableViaMMS__23CSendUiFileRightsEngineRC12MDesC16Array @ 38 NONAME R3UNUSED ; CSendUiFileRightsEngine::MMEFilesSendableViaMMS(MDesC16Array const &)
	MMEFilterAndNotifyNonMMSFilesL__23CSendUiFileRightsEngineR16CDesC16ArrayFlatG4TUid @ 39 NONAME R3UNUSED ; CSendUiFileRightsEngine::MMEFilterAndNotifyNonMMSFilesL(CDesC16ArrayFlat &, TUid)
	MtmCapabilitiesL__10CSendAppUiG4TUid @ 40 NONAME R3UNUSED ; CSendAppUi::MtmCapabilitiesL(TUid)
	MtmCapabilitiesL__11CSendBaseUiG4TUid @ 41 NONAME R3UNUSED ; CSendBaseUi::MtmCapabilitiesL(TUid)
	MtmForCommand__10CSendAppUii @ 42 NONAME R3UNUSED ; CSendAppUi::MtmForCommand(int)
	MtmForCommand__11CSendBaseUii @ 43 NONAME R3UNUSED ; CSendBaseUi::MtmForCommand(int)
	NewLC__10CSendAppUiiP15CEikHotKeyTable @ 44 NONAME R3UNUSED ; CSendAppUi::NewLC(int, CEikHotKeyTable *)
	NewLC__11CSendBaseUiiP15CEikHotKeyTable @ 45 NONAME R3UNUSED ; CSendBaseUi::NewLC(int, CEikHotKeyTable *)
	NewLC__23CSendUiFileRightsEngineRC3RFsRCi @ 46 NONAME R3UNUSED ; CSendUiFileRightsEngine::NewLC(RFs const &, int const &)
	NewLC__7CSendUi @ 47 NONAME R3UNUSED ; CSendUi::NewLC(void)
	NewL__10CSendAppUiiP15CEikHotKeyTable @ 48 NONAME R3UNUSED ; CSendAppUi::NewL(int, CEikHotKeyTable *)
	NewL__11CSendBaseUiiP15CEikHotKeyTable @ 49 NONAME R3UNUSED ; CSendBaseUi::NewL(int, CEikHotKeyTable *)
	NewL__12CMessageData @ 50 NONAME R3UNUSED ; CMessageData::NewL(void)
	NewL__15CSendingServiceRC4TUid @ 51 NONAME R3UNUSED ; CSendingService::NewL(TUid const &)
	NewL__19CSendingServiceInfo @ 52 NONAME R3UNUSED ; CSendingServiceInfo::NewL(void)
	NewL__7CSendUi @ 53 NONAME R3UNUSED ; CSendUi::NewL(void)
	ServiceCapabilitiesL__7CSendUiG4TUidR20TSendingCapabilities @ 54 NONAME R3UNUSED ; CSendUi::ServiceCapabilitiesL(TUid, TSendingCapabilities &)
	SetAddressL__15CMessageAddressRC7TDesC16 @ 55 NONAME R3UNUSED ; CMessageAddress::SetAddressL(TDesC16 const &)
	SetAliasL__15CMessageAddressRC7TDesC16 @ 56 NONAME R3UNUSED ; CMessageAddress::SetAliasL(TDesC16 const &)
	SetBodyTextL__12CMessageDataPC9CRichText @ 57 NONAME R3UNUSED ; CMessageData::SetBodyTextL(CRichText const *)
	SetServiceAddressL__19CSendingServiceInfoRC7TDesC16 @ 58 NONAME R3UNUSED ; CSendingServiceInfo::SetServiceAddressL(TDesC16 const &)
	SetServiceMenuNameL__19CSendingServiceInfoRC7TDesC16 @ 59 NONAME R3UNUSED ; CSendingServiceInfo::SetServiceMenuNameL(TDesC16 const &)
	SetServiceNameL__19CSendingServiceInfoRC7TDesC16 @ 60 NONAME R3UNUSED ; CSendingServiceInfo::SetServiceNameL(TDesC16 const &)
	SetSubjectL__12CMessageDataPC7TDesC16 @ 61 NONAME R3UNUSED ; CMessageData::SetSubjectL(TDesC16 const *)
	ShowQueryAndSendL__7CSendUiPC12CMessageDataG20TSendingCapabilitiesPt9CArrayFix1Z4TUidG4TUidiRC7TDesC16 @ 62 NONAME ; CSendUi::ShowQueryAndSendL(CMessageData const *, TSendingCapabilities, CArrayFix<TUid> *, TUid, int, TDesC16 const &)
	ShowSendQueryL__7CSendUiPC12CMessageDataG20TSendingCapabilitiesPt9CArrayFix1Z4TUidRC7TDesC16 @ 63 NONAME ; CSendUi::ShowSendQueryL(CMessageData const *, TSendingCapabilities, CArrayFix<TUid> *, TDesC16 const &)
	StartL__20CSendUiIdleMtmLoaderR11CMsvSession @ 64 NONAME R3UNUSED ; CSendUiIdleMtmLoader::StartL(CMsvSession &)
	ValidateServiceL__C7CSendUiG4TUidG20TSendingCapabilities @ 65 NONAME ; CSendUi::ValidateServiceL(TUid, TSendingCapabilities) const
	"_._10CSendAppUi" @ 66 NONAME R3UNUSED ; CSendAppUi::~CSendAppUi(void)
	"_._11CSendBaseUi" @ 67 NONAME R3UNUSED ; CSendBaseUi::~CSendBaseUi(void)
	"_._12CMessageData" @ 68 NONAME R3UNUSED ; CMessageData::~CMessageData(void)
	"_._15CMessageAddress" @ 69 NONAME R3UNUSED ; CMessageAddress::~CMessageAddress(void)
	"_._15CSendingService" @ 70 NONAME R3UNUSED ; CSendingService::~CSendingService(void)
	"_._19CSendingServiceInfo" @ 71 NONAME R3UNUSED ; CSendingServiceInfo::~CSendingServiceInfo(void)
	"_._7CSendUi" @ 72 NONAME R3UNUSED ; CSendUi::~CSendUi(void)
	__15CMessageAddress @ 73 NONAME R3UNUSED ; CMessageAddress::CMessageAddress(void)
	__20CSendUiIdleMtmLoaderR13CUidNameArrayR9CMtmStoreiP15CEikHotKeyTablei @ 74 NONAME ; CSendUiIdleMtmLoader::CSendUiIdleMtmLoader(CUidNameArray &, CMtmStore &, int, CEikHotKeyTable *, int)
	__20TSendingCapabilities @ 75 NONAME R3UNUSED ; TSendingCapabilities::TSendingCapabilities(void)
	AddSendMenuItemL__7CSendUiR12CEikMenuPaneiiG20TSendingCapabilities @ 76 NONAME ; CSendUi::AddSendMenuItemL(CEikMenuPane &, int, int, TSendingCapabilities)

